# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from elicitlabs import ElicitClient, AsyncElicitClient
from tests.utils import assert_matches_type
from elicitlabs.types.demo import OrgListOrganizationMembersResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestOrg:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_organization_members(self, client: ElicitClient) -> None:
        org = client.demo.org.list_organization_members(
            org_id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(OrgListOrganizationMembersResponse, org, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_organization_members(self, client: ElicitClient) -> None:
        response = client.demo.org.with_raw_response.list_organization_members(
            org_id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        org = response.parse()
        assert_matches_type(OrgListOrganizationMembersResponse, org, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_organization_members(self, client: ElicitClient) -> None:
        with client.demo.org.with_streaming_response.list_organization_members(
            org_id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            org = response.parse()
            assert_matches_type(OrgListOrganizationMembersResponse, org, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncOrg:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_organization_members(self, async_client: AsyncElicitClient) -> None:
        org = await async_client.demo.org.list_organization_members(
            org_id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(OrgListOrganizationMembersResponse, org, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_organization_members(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.org.with_raw_response.list_organization_members(
            org_id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        org = await response.parse()
        assert_matches_type(OrgListOrganizationMembersResponse, org, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_organization_members(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.org.with_streaming_response.list_organization_members(
            org_id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            org = await response.parse()
            assert_matches_type(OrgListOrganizationMembersResponse, org, path=["response"])

        assert cast(Any, response.is_closed) is True
